@@ -1,18 +1,24 @@
 /***************************************************************************
-                          ActionList.cpp  -  description
-                             -------------------
     begin                : Sun Oct 3 1999
     copyright            : (C) 1999 by Peter Putzer
     email                : putzer@kde.org
  ***************************************************************************/
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; version 2.                              *
- *                                                                         *
- ***************************************************************************/
+/*
+   This program is free software; you can redistribute it and/or
+   modify it under the terms of the GNU General Public
+   License as published by the Free Software Foundation; either
+   version 2 of the License, or (at your option) any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+*/
 
 #include <qapplication.h>
 #include "ksvdraglist.h"
@@ -28,7 +34,7 @@ KSVAction::KSVAction()
 
 KSVAction::~KSVAction()
 {
-  // default - shouldnt be used normally (pure virtual declaration)
+  // default - shouldn't be used normally (pure virtual declaration)
 }
 
 SimpleAction::SimpleAction (KSVDragList* s, const KSVData* i)
@@ -164,7 +170,7 @@ void ActionList::undoLast()
   if (!count())
     return;
 
-  KSVAction* a = QPtrStack<KSVAction>::pop();
+  KSVAction* a = Q3PtrStack<KSVAction>::pop();
   a->undo();
 
   emit undone();
@@ -184,7 +190,7 @@ void ActionList::redoLast()
   if (!count())
     return;
 
-  KSVAction* a = QPtrStack<KSVAction>::pop();
+  KSVAction* a = Q3PtrStack<KSVAction>::pop();
   a->redo();
 
   emit undone();
@@ -201,7 +207,7 @@ void ActionList::redoAll()
 
 void ActionList::push (KSVAction* a)
 {
-  QPtrStack<KSVAction>::push(a);
+  Q3PtrStack<KSVAction>::push(a);
 
   if (count() == 1)
     emit filled();
@@ -210,7 +216,7 @@ void ActionList::push (KSVAction* a)
 void ActionList::clear()
 {
   setAutoDelete (true);
-  QPtrStack<KSVAction>::clear();
+  Q3PtrStack<KSVAction>::clear();
   setAutoDelete (false);
 
   emit empty();
