@@ -4,38 +4,55 @@
     email                : putzer@kde.org
  ***************************************************************************/
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; version 2.                              *
- *                                                                         *
- ***************************************************************************/
+/*
+   This program is free software; you can redistribute it and/or
+   modify it under the terms of the GNU General Public
+   License as published by the Free Software Foundation; either
+   version 2 of the License, or (at your option) any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+*/
 
 #ifndef KSV_VIEW_H
 #define KSV_VIEW_H
 
 #include <qsplitter.h>
-#include <qvaluelist.h>
+#include <q3valuelist.h>
 #include <qsize.h>
+//Added by qt3to4:
+#include <QPixmap>
+#include <Q3CString>
+#include <QMoveEvent>
+#include <Q3Frame>
+#include <QLabel>
+#include <QShowEvent>
+#include <QResizeEvent>
+#include <Q3PopupMenu>
 
-#include <ktrader.h>
+#include <kmimetypetrader.h>
 
-class QPopupMenu;
+class Q3PopupMenu;
 class QFileInfo;
 class QLabel;
-class QListViewItem;
-class QTextEdit;
-class QFrame;
-class QVBox;
+class Q3ListViewItem;
+class Q3TextEdit;
+class Q3Frame;
+class Q3VBox;
 class QPixmap;
 class QLayout;
 
 class KScroller;
-class KProcess;
-class KListView;
+class K3Process;
+class K3ListView;
 class QSplitter;
-class KPopupMenu;
+class KMenu;
 class KSVTrash;
 class KSVDragList;
 class KSVConfig;
@@ -49,7 +66,7 @@ class KSVContent : public QSplitter
   Q_OBJECT
 
 public:
-  KSVContent (KPopupMenu* openWithMenu, KSVTopLevel* parent = 0, const char* name = 0);
+  KSVContent (KMenu* openWithMenu, KSVTopLevel* parent = 0, const char* name = 0);
   ~KSVContent();
 
   KSVDragList* getOrigin();
@@ -62,15 +79,15 @@ public:
                   const QColor& changedNormal,
                   const QColor& changedSelected);
 
-  void mergeLoadedPackage (QValueList<KSVData>* start,
-                           QValueList<KSVData>* stop);
+  void mergeLoadedPackage (Q3ValueList<KSVData>* start,
+                           Q3ValueList<KSVData>* stop);
 
 public slots:
   void slotWriteSysV();
 
   void infoOnData(KSVItem* data);
   void setDisplayScriptOutput(bool val);
-  void slotScriptProperties (QListViewItem*);
+  void slotScriptProperties (Q3ListViewItem*);
   void multiplexEnabled (bool);
 
   void hideRunlevel (int index);
@@ -92,13 +109,13 @@ private slots:
   void restartService (const QString& path);
   void editService();
   void editService (const QString& path);
-  void slotOutputOrError( KProcess* _p, char* _buffer, int _buflen );
-  void slotExitedProcess(KProcess* proc);
+  void slotOutputOrError( K3Process* _p, char* _buffer, int _buflen );
+  void slotExitedProcess(K3Process* proc);
   void slotScriptsNotRemovable();
-  void slotDoubleClick (QListViewItem*);
-  void slotExitDuringRestart(KProcess* proc);
+  void slotDoubleClick (Q3ListViewItem*);
+  void slotExitDuringRestart(K3Process* proc);
   void appendLog(const QString& rich, const QString& plain);
-  void appendLog(const QCString& _buffer);
+  void appendLog(const Q3CString& _buffer);
   void fwdCannotGenerateNumber();
   void fwdOrigin();
   void reSortRL();
@@ -106,8 +123,8 @@ private slots:
   void fwdUndoAction(KSVAction*);
   void updatePanningFactor();
 
-  void popupRunlevelMenu (KListView*, QListViewItem*, const QPoint&);
-  void popupServicesMenu (KListView*, QListViewItem*, const QPoint&);
+  void popupRunlevelMenu (K3ListView*, Q3ListViewItem*, const QPoint&);
+  void popupServicesMenu (K3ListView*, Q3ListViewItem*, const QPoint&);
 
   void updateServicesAfterChange (const QString&);
   void updateRunlevelsAfterChange ();
@@ -133,10 +150,10 @@ signals:
   void newOrigin();
 
 private:
-  static int splitterToPanningFactor (const QValueList<int>&);
-  static const QValueList<int>& panningFactorToSplitter (int);
+  static int splitterToPanningFactor (const Q3ValueList<int>&);
+  static const Q3ValueList<int>& panningFactorToSplitter (int);
 
-  void merge (QValueList<KSVData>& list, KSVDragList* widget);
+  void merge (Q3ValueList<KSVData>& list, KSVDragList* widget);
   void initLList();
   void initScripts();
   void initRunlevels();
@@ -146,22 +163,22 @@ private:
 
   friend class KSVTopLevel;
 
-  QFrame* mContent;
+  Q3Frame* mContent;
   KScroller* mScroller;
 
   KSVDragList** startRL;
   KSVDragList** stopRL;
   KSVDragList* scripts;
 
-  KPopupMenu* mItemMenu;
-  KPopupMenu* mContextMenu;
-  KPopupMenu* mScriptMenu;
+  KMenu* mItemMenu;
+  KMenu* mContextMenu;
+  KMenu* mScriptMenu;
   KSVTrash* trash;
-  QTextEdit* textDisplay;
+  Q3TextEdit* textDisplay;
   KSVConfig* conf;
 
-  QVBox* mScriptBox;
-  QVBox** mRunlevels;
+  Q3VBox* mScriptBox;
+  Q3VBox** mRunlevels;
   QWidget* mBuffer;
 
   KSVDragList* mOrigin;
@@ -170,10 +187,10 @@ private:
 
   QSize mMinSize;
 
-  KPopupMenu* mOpenWithMenu;
-  KTrader::OfferList mOpenWithOffers;
+  KMenu* mOpenWithMenu;
+  KServiceOfferList mOpenWithOffers;
 
-  QCString m_buffer;
+  Q3CString m_buffer;
 };
 
 #endif
