@@ -22,15 +22,15 @@
 */
 
 /*
-** Bug reports and questions can be sent to kde-devel@kde.org
+** Bug reports and questions can be sent to <kde-devel@kde.org>
 */
 
 #ifndef _INPUTBOX_H_
 #define _INPUTBOX_H_ 1
 #include <qdialog.h>
-#include <qlabel.h>
-#include <qlineedit.h>
-#include <qpushbutton.h>
+#include <QLabel>
+#include <QLineEdit>
+#include <QPushButton>
 #include "EditWidget.h"
 #include <list>
 class InputBox:public QDialog
@@ -39,7 +39,7 @@ class InputBox:public QDialog
 public:
 	typedef struct { QString label; QString dflt; bool isFile; QString help; } entry;
 	typedef std::list<entry> entries;
-	InputBox(entries e, QWidget *parent=0, const char *name=0, bool hasCancel=true, WFlags f=0);
+	explicit InputBox(entries e, QWidget *parent=0, const char *name=0, bool hasCancel=true, WFlags f=0);
 	QStringList const text() const { QStringList s; for(std::list<EditWidget*>::const_iterator it=edit.begin(); it!=edit.end(); it++) s << (*it)->text(); return s; };
 private:
 	std::list<EditWidget*> edit;
